==> unep_maps-2.0.1.zip: unep_maps/unep_maps.api.php <==
<?php

/**
 * @file
 * Hooks for unep_maps module.
 */

/**
 * Alters country data displayed on the map.
 * This hook can add a new country or overwrite country data used in mapbox:
 *
 * ISO3 code -  ios3 (string)
 * Popup content - popup (html string)
 * Link that opens on country click - link (url string)
 * Country background color - countryColor (HEX color code ?string)
 * Country hover color - countryHover (HEX color code ?string)
 *
 * @param array $countryData
 *   The data to alter.
 *
 * @return void
 */
function hook_unep_maps_country_data_alter(array &$countryData) {
  $countryData[] = [
    'iso3' => 'TWN',
    'popup' => 'Taiwan, Province of China',
    'link' => '/countries/chn',
    'color' => '#8FA1FA',
    'hoverColor' => '#637CF8',
  ];

  $countryData[] = [
    'iso3' => 'FLK',
    'popup' => 'Falkland Islands (Malvinas)',
    'link' => '/countries/gbr',
    'color' => '#8FA1FA',
    'hoverColor' => '#637CF8',
  ];
}

/**
 * Alters pin data displayed on the map.
 * This hook can add a new pin or overwrite pin data used in mapbox:
 *
 * Coordinates - array [lon, lat]
 * Popup content - popup (html string)
 *
 * @param array $pinData
 *   The data to alter.
 *
 * @return void
 */
function hook_unep_maps_pin_data_alter(array &$pinData) {
  $pinData[] = [
    'coordinates' => [-74.0060, 40.7128],
    'popup' => 'New York, United States',
  ];
}

/**
 * Alters area data displayed on the map.
 * This hook can add a new area polygon or overwrite polygons data used in mapbox using geometry features.
 *
 * @param array $areaData
 *   The data to alter.
 *
 * @return void
 */
function hook_unep_maps_area_data_alter(array &$areaData) {
  $wktPolygon = 'MULTIPOLYGON(
  (
    (2.30 48.84, 2.30 48.90, 2.40 48.90, 2.40 48.84, 2.30 48.84)
  ),
  (
    (2.50 48.84, 2.50 48.90, 2.60 48.90, 2.60 48.84, 2.50 48.84)
  )
)';

  $geometry = GeoPHP::load($wktPolygon, 'wkt');
  $geoJsonGeometry = json_decode($geometry->out('json'), TRUE);

  $geoJsonFeature = [
    'type' => 'Feature',
    'geometry' => $geoJsonGeometry,
    'properties' => [
      'id' => 'new-polygon',
      'popup' => 'New zone',
    ],
  ];

  $areaData[] = $geoJsonFeature;
}

==> unep_maps-2.0.2.zip: unep_maps/unep_maps.api.php <==
<?php

/**
 * @file
 * Hooks for unep_maps module.
 */

/**
 * Alters country data displayed on the map.
 * This hook can add a new country or overwrite country data used in mapbox:
 *
 * ISO3 code -  ios3 (string)
 * Popup content - popup (html string)
 * Link that opens on country click - link (url string)
 * Country background color - countryColor (HEX color code ?string)
 * Country hover color - countryHover (HEX color code ?string)
 *
 * @param array $countryData
 *   The data to alter.
 *
 * @return void
 */
function hook_unep_maps_country_data_alter(array &$countryData) {
  $countryData[] = [
    'iso3' => 'TWN',
    'popup' => 'Taiwan, Province of China',
    'link' => '/countries/chn',
    'color' => '#8FA1FA',
    'hoverColor' => '#637CF8',
  ];

  $countryData[] = [
    'iso3' => 'FLK',
    'popup' => 'Falkland Islands (Malvinas)',
    'link' => '/countries/gbr',
    'color' => '#8FA1FA',
    'hoverColor' => '#637CF8',
  ];
}

/**
 * Alters pin data displayed on the map.
 * This hook can add a new pin or overwrite pin data used in mapbox:
 *
 * Coordinates - array [lon, lat]
 * Popup content - popup (html string)
 *
 * @param array $pinData
 *   The data to alter.
 *
 * @return void
 */
function hook_unep_maps_pin_data_alter(array &$pinData) {
  $pinData[] = [
    'coordinates' => [-74.0060, 40.7128],
    'popup' => 'New York, United States',
  ];
}

/**
 * Alters area data displayed on the map.
 * This hook can add a new area polygon or overwrite polygons data used in mapbox using geometry features.
 *
 * @param array $areaData
 *   The data to alter.
 *
 * @return void
 */
function hook_unep_maps_area_data_alter(array &$areaData) {
  $wktPolygon = 'POLYGON ((9.0 46.5, 12.5 45.8, 14.0 43.5, 15.5 41.0, 14.0 38.5, 11.5 40.0, 10.0 43.0, 9.0 46.5))';

  $geometry = GeoPHP::load($wktPolygon, 'wkt');
  $geoJsonGeometry = json_decode($geometry->out('json'), TRUE);

  $geoJsonFeature = [
    'type' => 'Feature',
    'geometry' => $geoJsonGeometry,
    'properties' => [
      'id' => 'new-polygon',
      'popup' => 'New zone',
      'color' => '#8FA1FA',
      'hoverColor' => "#637CF8",
    ],
  ];

  $areaData['features'][] = $geoJsonFeature;
}
